#!/bin/sh
# _rtbdelta.sh
#  This file must be saved with Unix EOL in order to ensure compatiblity with deployment made via the Win32 client. 

# Check repository information and O/S files for differences.
# TEMPFILE1 is the repository file.  TEMPFILE2 is a file composed of O/S source
# that is combined to emulate the repository file.  After these files are
# built, they are CRC checked and diff'ed for differences.  The results of
# these two checks is placed into a third file DELTAFILE.  The DELTAFILE is
# parsed by other programs.  The CRC value is the first line of the file.  It 
# can be read and processed.  If the DELTAFILE contains more than one line, it
# is assumed the diff found differences and the repository information and
# O/S source is different.

# type of file be processed.  Either "B" (binary) or "S" (source)
FTYPE=$1
shift

# the CRC utility to CRC the files.  If "nocrc" then no CRC is performed
CRCUTIL=$1
shift

# Does this object contain a WRX?  If "wrx" then uuencoding of 10th part happens
WRX=$1
shift

# file that contains the source as it exists in the repository
TEMPFILE1=$1
shift

# file that is built from source.  It will emulate the repo file
TEMPFILE2=$1
shift

# file that contains the CRC value, and result of diff
DELTAFILE=$1
shift

# Note: also passed to as arguments.  The fully quantified name of the O/S
# source.  Each part of the source is passed as its own argument.

# ----------------------------------------------------------------------------

# remove tempfile2 if it exists
test -f ${TEMPFILE2} && rm ${TEMPFILE2}

# Since an object can contain 10 parts, loop 10 time and skip any blank parts. We
# cannot stop at the first blank part because EOF markers ("E") are needed for the
# blank parts when a 10th part (WRX file) exists.  Each part is parsed with 'sed' to
# add a blank space at the beginning of each line.  Binary parts are uuencoded with
# the uuencode header being modifed for the WRX part.  The output is placed into
# TEMPFILE2.
i=1

while [ $i != 11 ]
do 
  
  if [ $i = 10 ] && [ "$1" != "" ]
  then
    # yes, the newline at the end of the line below is intentional
    test -f "$1" && uuencode "$1" placeholder | sed -e 's/^/ /' -e '1c\
 begin 777 xxxx' >> ${TEMPFILE2}

  elif [ "${FTYPE}" = "B" ] && [ "$1" != "" ]
  then
    test -f "$1" && uuencode "$1" placeholder | sed -e 's/^/ /' >> ${TEMPFILE2}
  
  elif [ "$1" != "" ]
  then
    # In addition to adding a space, we are removing the ending CR from the each line in tempfile2 in case the
    # Object was saved with DOS EOL. This is represented below with an embedded CR (ctrl-V, ctrl-M).
    test -f "$1" && cat "$1" | sed -e 's/^/ /;s/
$//' >> ${TEMPFILE2}
  fi
  
  # Insert an "E" to indicate end of part
  if [ "$1" != "" ] || [ "${WRX}" = "wrx" ]
  then 
    echo "E" >> ${TEMPFILE2}
  fi

  shift
  
  i=`expr $i + 1`
  
done 

# perform CRC check, and put result into line 1 of DELTAFILE
if [ "${CRCUTIL}" = "nocrc" ] 
then 
   echo "0" > ${DELTAFILE}
else
   ${CRCUTIL} ${TEMPFILE2} > ${DELTAFILE}
fi

# perform diff and append result into DELTAFILE
diff -e ${TEMPFILE1} ${TEMPFILE2} >> ${DELTAFILE}
